@@ -3,11 +3,11 @@ __license__ = "Apache-2.0"
 
 # do not change this line manually
 # this is managed by git tag and updated on every release
-__version__ = '0.1.7'
+__version__ = '0.1.11'
 
 # do not change this line manually
 # this is managed by proto/build-proto.sh and updated on every execution
-__proto_version__ = '0.0.20'
+__proto_version__ = '0.0.21'
 
 import platform
 import sys
@@ -52,10 +52,12 @@ __jina_env__ = ('JINA_ARRAY_QUANT',
                 'JINA_LOG_PROFILING',
                 'JINA_LOG_SSE',
                 'JINA_LOG_VERBOSITY',
+                'JINA_POD_NAME',
                 'JINA_PROFILING',
                 'JINA_SOCKET_HWM',
                 'JINA_STACK_CONFIG',
                 'JINA_TEST_CONTAINER',
+                'JINA_TEST_GPU',
                 'JINA_TEST_PRETRAINED',
                 'JINA_VCS_VERSION',
                 'JINA_VERSION',
